#!/bin/bash
ScriptDir="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"
cwd=$(pwd)

function usage() {
    echo "Usage: "
    echo "./ctl.sh [command] --version [version] --customer [the-name-of-the-customer] --deployment [name] --path [path-to-create]"
    echo ""
    echo "Command: "
    echo "info    -  information about project"
    echo "create   - creates a new Everyware project using starter kit"
    echo ""
    echo "Mandatory Options: "
    echo "--customer    [value]          the customer name"
    echo ""
    echo "Optional Options: "
    echo "--version     [version]        the version of the starter kit to install from. Will default to master"
    echo "--deployment  [value]          the name of the deployment wanted common values : stage, test, prod. Will default to test"
    echo "--path        [value]          the path to create the project"
    echo ""
}

# Stack name will be set by the script
RootDir=~
Customer=
Version=latest
Deployment=test

# Read arguments
POSITIONAL=()
while [[ $# -gt 0 ]]
do
    key="$1"
    case ${key} in
        -h|--help)
            echo "USAGE:"
            usage
            exit 0
            shift # past argument
            ;;
        --customer)
           Customer=${2}
           shift # past argument
           shift # past argument
        ;;
        --deployment)
          Deployment=${2}
          shift # past argument
          shift # past argument
        ;;
        --version)
          Version=${2}
          shift # past argument
          shift # past argument
        ;;
        --path)
            RootDir=${2}
            shift # past argument
            shift # past argument
        ;;
        *)    # unknown option
           POSITIONAL+=("$1") # save it in an array for later
           shift # past argument
        ;;
    esac
done
set -- "${POSITIONAL[@]}" # restore positional parameters
# Done reading arguments

CMD=${1}

# command mandatory
if [[ -z ${CMD} ]]; then
    echo "ERROR: command missing"
    exit 1
fi

if [[ -z ${Customer} ]] || [[ ${Customer} == "" ]]; then
    echo "ERROR: --customer missing"
    exit 1
fi

if [[ -z ${Deployment} ]]; then
    echo "ERROR: --deployment missing"
    exit 1
fi

if [[ -z ${RootDir} ]]; then
    echo "ERROR: --path missing"
    exit 1
fi

# Create a place to work
InstallationDir=${RootDir}/${Customer}

case ${CMD} in
    create)
        # clone the default project
        if [[ ${Version} == "latest" ]] || [[ ${Version} == "master" ]]; then
            git clone git@bitbucket.org:infomaker/everyware-starter-kit.git ${InstallationDir}
        else
            git clone --branch ${Version} git@bitbucket.org:infomaker/everyware-starter-kit.git ${InstallationDir}
        fi

        cd ${InstallationDir}

        # Checkout latest tag if requested
        if [[ ${Version} == "latest" ]]; then

            git fetch --tags

            # Get the latest tag name
            LatestTag=$(git describe --tags `git rev-list --tags --max-count=1`)

            # Checkout the latest tag
            git checkout ${LatestTag}

            echo "Installing from latest version: ${LatestTag}"

        elif [[ ${Version} == "master" ]]; then

            echo "Installing from master"
        else
            echo "Installing from version: ${Version}"
        fi

        # Remove git
        rm -rf .git
    ;;
esac

cd ${cwd}
