<?php declare(strict_types=1);

namespace Everyware\Installer\Console\Providers;

use Everyware\Installer\Console\Contracts\StarterKitProvider;

/**
 * Class BitbucketProvider
 * @package Everyware\Installer\Console\Providers
 */
class BitbucketProvider implements StarterKitProvider
{
    public const REPOSITORY = 'git@bitbucket.org:infomaker/everyware-starter-kit.git';
    private $messages = [];
    private $path;
    private $version;

    /**
     * Download Starter kit and return the path
     *
     * @param string $version
     * @param string $path Where the Starter kit should be downloaded to
     *
     * @return string The path to where the starter kit was placed
     */
    public function download(string $version, string $path): string
    {
        $this->path = $path;
        $this->version = $version;
        switch ($version) {
            case 'latest':
                $this->downloadLatest();
                break;
            case 'master':
                $this->downloadMaster();
                break;
            default:
                $this->cloneRepo(static::REPOSITORY, $path, $version);
        }

        return $this->path;
    }

    private function cloneRepo($repo, $path = '', $branch = ''): string
    {
        if ( ! empty($branch)) {
            return exec(sprintf('git clone --branch %s %s %s', $branch, $repo, $path), $this->messages);
        }

        return exec(sprintf('git clone %s %s', $repo, $path), $this->messages);
    }

    private function downloadLatest()
    {
        $this->downloadMaster();
        $this->moveIntoRepo();
        $latestTag = $this->moveToLatestVersion();
        var_dump( $latestTag );
    }


    private function downloadMaster(): void
    {
        $this->cloneRepo(static::REPOSITORY, $this->path);
    }

    private function moveIntoRepo()
    {
        return exec("cd {$this->path}", $this->messages);
    }

    private function moveToLatestVersion()
    {
        return exec('$(git describe --tags `git rev-list --tags --max-count=1`)', $this->messages);
    }
}
